@@ -16,7 +16,7 @@ from .classtemplate import *
 from .constructor import *
 from .conversionfunction import *
 from .cstruct import *
-from .ctype import *
+from .ctype import Type
 from .destructor import *
 from .enum import *
 from .enumvalue import *
@@ -27,7 +27,6 @@ from .method import *
 from .namespace import *
 from .node import *
 from .root import *
-from .templatetype import *
 from .typedef import *
 from .union import *
 from .variable import *
