@@ -13,38 +13,38 @@
 from cldoc.clang import cindex
 from node import Node
 
-kindmap = {
-    cindex.TypeKind.POINTER: '*',
-    cindex.TypeKind.LVALUEREFERENCE: '&',
-}
-
-namemap = {
-    cindex.TypeKind.VOID: 'void',
-    cindex.TypeKind.BOOL: 'bool',
-    cindex.TypeKind.CHAR_U: 'char',
-    cindex.TypeKind.UCHAR: 'unsigned char',
-    cindex.TypeKind.CHAR16: 'char16_t',
-    cindex.TypeKind.CHAR32: 'char32_t',
-    cindex.TypeKind.USHORT: 'unsigned short',
-    cindex.TypeKind.UINT: 'unsigned int',
-    cindex.TypeKind.ULONG: 'unsigned long',
-    cindex.TypeKind.ULONGLONG: 'unsigned long long',
-    cindex.TypeKind.UINT128: 'uint128_t',
-    cindex.TypeKind.CHAR_S: 'char',
-    cindex.TypeKind.SCHAR: 'signed char',
-    cindex.TypeKind.WCHAR: 'wchar_t',
-    cindex.TypeKind.SHORT: 'unsigned short',
-    cindex.TypeKind.INT: 'int',
-    cindex.TypeKind.LONG: 'long',
-    cindex.TypeKind.LONGLONG: 'long long',
-    cindex.TypeKind.INT128: 'int128_t',
-    cindex.TypeKind.FLOAT: 'float',
-    cindex.TypeKind.DOUBLE: 'double',
-    cindex.TypeKind.LONGDOUBLE: 'long double',
-    cindex.TypeKind.NULLPTR: 'float',
-}
-
 class Type(Node):
+    kindmap = {
+        cindex.TypeKind.POINTER: '*',
+        cindex.TypeKind.LVALUEREFERENCE: '&',
+    }
+
+    namemap = {
+        cindex.TypeKind.VOID: 'void',
+        cindex.TypeKind.BOOL: 'bool',
+        cindex.TypeKind.CHAR_U: 'char',
+        cindex.TypeKind.UCHAR: 'unsigned char',
+        cindex.TypeKind.CHAR16: 'char16_t',
+        cindex.TypeKind.CHAR32: 'char32_t',
+        cindex.TypeKind.USHORT: 'unsigned short',
+        cindex.TypeKind.UINT: 'unsigned int',
+        cindex.TypeKind.ULONG: 'unsigned long',
+        cindex.TypeKind.ULONGLONG: 'unsigned long long',
+        cindex.TypeKind.UINT128: 'uint128_t',
+        cindex.TypeKind.CHAR_S: 'char',
+        cindex.TypeKind.SCHAR: 'signed char',
+        cindex.TypeKind.WCHAR: 'wchar_t',
+        cindex.TypeKind.SHORT: 'unsigned short',
+        cindex.TypeKind.INT: 'int',
+        cindex.TypeKind.LONG: 'long',
+        cindex.TypeKind.LONGLONG: 'long long',
+        cindex.TypeKind.INT128: 'int128_t',
+        cindex.TypeKind.FLOAT: 'float',
+        cindex.TypeKind.DOUBLE: 'double',
+        cindex.TypeKind.LONGDOUBLE: 'long double',
+        cindex.TypeKind.NULLPTR: 'float',
+    }
+
     def __init__(self, tp):
         Node.__init__(self, None, None)
 
@@ -57,15 +57,36 @@ class Type(Node):
         self.extract(tp)
 
     @property
-    def is_array(self):
+    def is_constant_array(self):
         return self.tp.kind == cindex.TypeKind.CONSTANTARRAY
 
+    @property
+    def is_out(self):
+        if hasattr(self.tp, 'is_out'):
+            return self.tp.is_out
+        else:
+            return False
+
+    @property
+    def transfer_ownership(self):
+        if hasattr(self.tp, 'transfer_ownership'):
+            return self.tp.transfer_ownership
+        else:
+            return 'none'
+
+    @property
+    def allow_none(self):
+        if hasattr(self.tp, 'allow_none'):
+            return self.tp.allow_none
+        else:
+            return False
+
     @property
     def element_type(self):
         return self._element_type
 
     @property
-    def array_size(self):
+    def constant_array_size(self):
         return self._array_size
 
     def _full_typename(self, decl):
@@ -89,9 +110,12 @@ class Type(Node):
         if tp.is_const_qualified():
             self._qualifier.append('const')
 
-        if tp.kind in kindmap:
+        if hasattr(tp, 'is_builtin'):
+            self._builtin = tp.is_builtin()
+
+        if tp.kind in Type.kindmap:
             self.extract(tp.get_pointee())
-            self._qualifier.append(kindmap[tp.kind])
+            self._qualifier.append(Type.kindmap[tp.kind])
 
             return
         elif tp.kind == cindex.TypeKind.CONSTANTARRAY:
@@ -102,9 +126,11 @@ class Type(Node):
 
         if self._decl and self._decl.displayname:
             self._typename = self._full_typename(self._decl)
-        elif tp.kind in namemap:
-            self._typename = namemap[tp.kind]
+        elif tp.kind in Type.namemap:
+            self._typename = Type.namemap[tp.kind]
             self._builtin = True
+        elif tp.kind != cindex.TypeKind.CONSTANTARRAY and hasattr(tp, 'spelling'):
+            self._typename = tp.spelling
         else:
             self._typename = ''
 
@@ -114,13 +140,13 @@ class Type(Node):
 
     @property
     def typename(self):
-        if self.is_array:
+        if self.is_constant_array:
             return self._element_type.typename
         else:
             return self._typename
 
     def typename_for(self, node):
-        if self.is_array:
+        if self.is_constant_array:
             return self._element_type.typename_for(node)
 
         if not node or not '::' in self._typename:
@@ -136,4 +162,16 @@ class Type(Node):
     def qualifier(self):
         return self._qualifier
 
+    @property
+    def qualifier_string(self):
+        ret = ''
+
+        for x in self._qualifier:
+            if x != '*' or (len(ret) != 0 and ret[-1] != '*'):
+                ret += ' '
+
+            ret += x
+
+        return ret
+
 # vi:ts=4:et
